[![CodeFactor](https://www.codefactor.io/repository/github/hexagoncore/input_num/badge)](#/)
[<img src="https://img.shields.io/github/license/HexagonCore/input_num">](#/)
[<img src="https://img.shields.io/github/stars/HexagonCore/input_num">](#/)
[<img src="https://img.shields.io/github/forks/HexagonCore/input_num">](#/)
[<img src="https://img.shields.io/github/issues/HexagonCore/input_num">](#/)


# input_num
Python package - **input_num** is like input but it **only accepts numbers**
___
### ‎

## Instalation
* ### Windows / macOS
	Run `python3 -m pip install input_num`
	
* ### Linux
	Run `python3 -m pip install input_num`
### ‎

## Usage
* ### Windows / macOS / Linux
	Add this to your script:
	`import input_num`
	`input_num("Enter your age: ")`
	
	If you want to allow only positive numbers (numbers WITHOUT **-** at the begining), use `input_num("Something", False)`.
	*False* just means **Allow negative numbers = False**
	And it is **optional argument**
	 ‎
	
	

### ‎

## Uninstallation
* ### Windows / macOS
	Run `python3 -m pip uninstall input_num`
	
* ### Linux
	Run `python3 -m pip uninstall input_num`

### ‎
## FAQ
* ### Question
	Answernot enough
### ‎


Do you like this? Hit that ⭐!                                
Use the star button as way to show us, that it works              
Forks and pull requests are welcome of course
 

